@@ -1,3 +1,31 @@
+# Copyright (c) 2012-2013, Itzik Kotler
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
+#
+#     * Redistributions of source code must retain the above copyright
+#       notice, this list of conditions and the following disclaimer.
+#
+#     * Redistributions in binary form must reproduce the above copyright
+#       notice, this list of conditions and the following disclaimer in the
+#       documentation and/or other materials provided with the distribution.
+#
+#     * Neither the name of the author nor the names of its contributors may
+#       be used to endorse or promote products derived from this software without
+#       specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY
+# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
 import re
 import ast
 import _ast
@@ -209,13 +237,19 @@ def preprocessor(buffer, stmt_as_is, tries=0):
 
             if isinstance(node, _ast.Print):
 
-                new_buffer = '__builtins__.print_'
+                new_buffer = 'print_'
 
                 # "Module(body=[Print(dest=None, values=[Str(s='Hello World')], nl=True)])"
 
                 if node.values:
 
-                    new_buffer = '__builtins__.print_(' + codegen.to_source(node)[5:] + ')'
+                    if isinstance(node.values[0], _ast.Compare):
+
+                        new_buffer = 'print_(' + buffer.replace('print','') + ')'
+
+                    else:
+
+                        new_buffer = 'print_(' + codegen.to_source(node)[5:] + ')'
 
                 # It's (a) Python and (b) expression
 
